==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/debug.js <==
/**
 * @brief   JS Object debug funtion
 * @author  DRZ 10.03.2005
 */
function inspect(obj,win) {
	var str = "";

	for(var prop in obj)
		try{
			str += "obj." + prop + " = " + obj[prop] + (win?"<br>":"\r\n");
		}
		catch(er){
			str += 'obj.' + prop + " = NO ACCESS" + (win?"<br>":"\r\n");
		};

	if (win){
		var kokos = window.open("","");
		kokos.document.writeln(str);
	}
	else
		alert(str);
};

/**
 * @brief: JS multidimensional array debug funtion
 * @input: array
 * @date : 21.7.2006 10:45:05
 */
function inspect2(arr,win){

	if (win){
		var kokos = window.open("","");
		kokos.document.writeln(var_dump(arr).replace(/\n/g,"<br>"));
	}
	else
		alert(var_dump(arr));
};


function var_dump(arr,fce,num){
	var ap="",out="",tstr="";
	num = num || 0;

	if (Is.String(arr)) return arr;

	for (var ii=0; ii<num; ii++) ap += ".";
	for (var i in arr){

		if (typeof arr[i] == 'object')
			out += ap+" ["+i+"]\r\n" + var_dump(arr[i],fce,num+2);
		else{
			if (typeof arr[i] == 'undefined')
				tstr = 'undefined'; //continue;
			else
				tstr = arr[i].toString();

			out += ap+" ["+i+"]("+typeof arr[i] +") = "+tstr+"\r\n";
		}

	}
	return out;
};

/**
 * @brief: AJAX debuging object
 * @date : 24.5.2006 15:28:57
 **/
var IWAPI_DEBUG = false;
_me = cAPI_debug.prototype;
function cAPI_debug(){
	/* set DEBUG MODE */
	window.IWAPI_DEBUG = true;
};

_me.add = function(title,data){
	/* open debug window */
	if (!this.win || this.win.closed) this.open();

	data = data || 'no data';

	var e0 = mkElement('div');
	var e1 = mkElement('div');
		e1.innerHTML= '<span>[+]</span> ' + title;
		e1.onclick = function(){
			var s,t,ns = this.nextSibling.style;
			if (ns.display=='none'){
				ns.display = "block";
				t = '[-]';
			}else{
				ns.display = "none";
				t = '[+]';
			}
			this.getElementsByTagName('span')[0].innerHTML = t;
		};

	var e2 = mkElement('pre');
		e2.style.display = 'none';

	if (typeof data=='object')
		e2.innerHTML = var_dump(data);
	else
		e2.innerHTML = data;

	this.win.document.body.appendChild(e0);
	e0.appendChild(e1);
	e0.appendChild(e2);
	e0 = null; e1 = null; e2 = null;
};

_me.open = function(){
	this.win = window.open('', 'debug', "resizable=yes,scrollbars=1,status=0,width=400,height=600");
	this.win.document.body.innerHTML = '';
	this.win.focus();
	this.win.stop(true);
};

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/debug.js <==
/**
 * @brief   JS Object debug funtion
 * @author  DRZ 10.03.2005
 */
function inspect(obj,win) {
	var str = "";

	for(var prop in obj)
		try{
			str += "obj." + prop + " = " + obj[prop] + (win?"<br>":"\r\n");
		}
		catch(er){
			str += 'obj.' + prop + " = NO ACCESS" + (win?"<br>":"\r\n");
		};

	if (win){
		var kokos = window.open("","");
		kokos.document.writeln(str);
	}
	else
		alert(str);
};

/**
 * @brief: JS multidimensional array debug funtion
 * @input: array
 * @date : 21.7.2006 10:45:05
 */
function inspect2(arr,win){

	if (win){
		var kokos = window.open("","");
		kokos.document.writeln(var_dump(arr).replace(/\>/g,"&gt;").replace(/\</g,"&lt;").replace(/\n/g,"<br>"));
	}
	else
		alert(var_dump(arr));
};


function var_dump(arr,fce,num){
	var ap="",out="",tstr="";
	num = num || 0;

	if (Is.String(arr)) return arr;

	for (var ii=0; ii<num; ii++) ap += ".";
	for (var i in arr){

		if (typeof arr[i] == 'object')
			out += ap+" ["+i+"]\r\n" + var_dump(arr[i],fce,num+2);
		else{
			if (typeof arr[i] == 'undefined')
				tstr = 'undefined'; //continue;
			else
				tstr = arr[i].toString();

			out += ap+" ["+i+"]("+typeof arr[i] +") = "+tstr+"\r\n";
		}

	}
	return out;
};

/**
 * @brief: AJAX debuging object
 * @date : 24.5.2006 15:28:57
 **/
var IWAPI_DEBUG = false;
_me = cAPI_debug.prototype;
function cAPI_debug(){
	/* set DEBUG MODE */
	window.IWAPI_DEBUG = true;
};

_me.add = function(title,data){
	/* open debug window */
	if (!this.win || this.win.closed) this.open();

	data = data || 'no data';

	var e0 = mkElement('div');
	var e1 = mkElement('div');
		e1.innerHTML= '<span>[+]</span> ' + title;
		e1.onclick = function(){
			var s,t,ns = this.nextSibling.style;
			if (ns.display=='none'){
				ns.display = "block";
				t = '[-]';
			}else{
				ns.display = "none";
				t = '[+]';
			}
			this.getElementsByTagName('span')[0].innerHTML = t;
		};

	var e2 = mkElement('pre');
		e2.style.display = 'none';

	if (typeof data=='object')
		e2.innerHTML = var_dump(data);
	else
		e2.innerHTML = data;

	this.win.document.body.appendChild(e0);
	e0.appendChild(e1);
	e0.appendChild(e2);
	e0 = null; e1 = null; e2 = null;
};

_me.open = function(){
	this.win = window.open('', 'debug', "resizable=yes,scrollbars=1,status=0,width=400,height=600");
	this.win.document.body.innerHTML = '';
	this.win.focus();
	this.win.stop(true);
};

/*
//DEBUG 1
var date = new Date();
var t1 = date.getSeconds() + (date.getMilliseconds()/1000);

//DEBUG2
date = new Date();
var t2 = date.getSeconds() + (date.getMilliseconds()/1000);
document.title = t2 - t1;
*/
